<template>
  <el-dialog
    v-dialogDrag
    title="历史驳回详情"
    :visible="visible"
    :append-to-body="true"
    :before-close="handleClose"
    :close-on-click-modal="false"
    v-if="visible"
    width="70vw"
    :class="[loading ? 'dialog-box' : '']"
  >
    <div
      v-loading="loading"
      element-loading-text="加载中..."
      element-loading-spinner="el-icon-loading"
      element-loading-background="rgba(255, 255, 255, 1)"
    >
      <div>
        <el-table
          stripe
          v-loading="loading"
          ref="multipleSelection"
          :data="tableData"
          :max-height="tableMaxHeight"
          :style="{width: '100%'}"
        >
          <el-table-column
            type="index"
            width="60"
            label="序号"
            align="center"
          ></el-table-column>
          <el-table-column
            prop="eventNum"
            width="220"
            show-overflow-tooltip
            label="事件编号"
            align="center"
          >
          </el-table-column>
          <el-table-column
            prop="operateUserName"
            width="120"
            show-overflow-tooltip
            label="驳回人"
            align="center"
          >
          </el-table-column>
          <el-table-column
            align="center"
            label="驳回时间"
            width="150"
            prop="operateDate"
            show-overflow-tooltip
          >
          </el-table-column>
          <el-table-column
            show-overflow-tooltip
            label="驳回环节"
            prop="createTime"
            width="120"
            align="center">
            <template v-slot="{row}">
              <el-link type="primary">{{ getDictName('xjggqk_shzt', row.status) }}</el-link>
            </template>
          </el-table-column>
          <el-table-column
            label="驳回理由"
            show-overflow-tooltip
            prop="approvalComments"
            align="center">
          </el-table-column>
        </el-table>
      </div>
    </div>
  </el-dialog>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import countyApi from '@/api/ReformSituation/countyApi'
import utils from '@/utils'
export default {
  name: 'refusalDialog',
  mixins: [TableMixin],
  props: {},
  data() {
    return {
      visible: false,
      loading:false,
      tableData:[],
    }
  },
  created() {
  },
  methods: {
    upDate(item) {
      this.visible = true
      this.getDetails(item)
    },
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    // 详情回显
    getDetails(item){
      this.loading = true
      let param = {
        unitId:item.unitId,
        year:item.fillYear,
        month:item.fillMonth
      }
      countyApi.turnDownChange(param).then(res => {
        this.tableData = res
        this.loading = false
      })
    },
    // 取消
    handleClose() {
      this.visible = false
    },
  }
}
</script>
<style lang="css">
.el-tooltip__popper {
  max-width: 40%;
}
</style>
<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';
</style>
